import Maybe, {} from 'true-myth/maybe';
import Result from 'true-myth/result';
import { isString } from '@sindresorhus/is';
import { InvalidArgumentError } from 'commander';
export function createCliRunOptions(options) {
    const { versionNumber, commandOptions, changelogPath } = options;
    const unreleased = commandOptions.unreleased === true;
    const commonRunOptions = {
        sloppy: commandOptions.sloppy === true,
        changelogPath,
        stdout: commandOptions.stdout === true,
        unreleased
    };
    if (unreleased) {
        if (isString(versionNumber)) {
            return Result.err(new InvalidArgumentError('A version number is not allowed when --unreleased was provided'));
        }
        return Result.ok({
            ...commonRunOptions,
            unreleased: true,
            versionNumber: Maybe.nothing()
        });
    }
    return Maybe.of(versionNumber).match({
        Just(value) {
            return Result.ok({
                ...commonRunOptions,
                unreleased: false,
                versionNumber: Maybe.just(value)
            });
        },
        Nothing() {
            return Result.err(new InvalidArgumentError('Version number is missing'));
        }
    });
}
//# sourceMappingURL=cli-run-options.js.map